@@ -21,4 +21,8 @@ if (getRversion() >= "2.15.1")
       'SE_MAAPE'
     )
 
-  )
\ No newline at end of file
+  )
+
+.onUnload <- function (libpath) {
+  library.dynam.unload("BMTME", libpath)
+}
\ No newline at end of file
